/*
 * Copyright (c) 2004-2007 Erez Zadok
 * Copyright (c) 2004-2007 Stony Brook University
 * Copyright (c) 2004-2007 The Research Foundation of State University of New York
 * Copyright (c) 2004-2007 Nikolai Joukov
 *
 * For specific licensing information, see the COPYING file distributed with
 * this package, or get one from ftp://ftp.filesystems.org/pub/fist/COPYING.
 *
 * This Copyright notice must be kept intact and distributed with all
 * fistgen sources INCLUDING sources generated by fistgen.
 */

#ifndef __DEBUG_H
#define __DEBUG_H

//ERROR SETTINGS
#define ERROR_MESSAGES 1
#define WARNING_MESSAGES 1

//DEBUG SETTINGS
#define DEBUG_VALUES 0

#if DEBUG_VALUES
#define print_debug_int(VAR,VAL) printk(KERN_ALERT "DEBUG: %s() - %s = %d\n",__FUNCTION__,VAR,VAL)
#define print_debug_addr(VAR,VAL) printk(KERN_ALERT "DEBUG: %s() - %s = %x\n",__FUNCTION__,VAR,(int)VAL)
#define print_debug_string(VAR,STR) printk(KERN_ALERT "DEBUG: %s() - %s = %s\n",__FUNCTION__,VAR,STR)
#define print_debug_location(LOC) printk(KERN_ALERT "DEBUG: %s() - %s\n",__FUNCTION__,LOC)
#define print_debug_message(FORMAT,ARGS...) do{\
             printk(KERN_ALERT "DEBUG: %s() - ",__FUNCTION__); \
             printk(KERN_ALERT FORMAT,##ARGS); \
             printk(KERN_ALERT "\n"); \
             }while(0)
#else //#if DEBUG_VALUES
#define print_debug_int(VAR,VAL)
#define print_debug_addr(VAR,VAL)
#define print_debug_string(VAR,VAL)
#define print_debug_location(LOC)
#define print_debug_message(FORMAT,ARGS...)
#endif //#if DEBUG_VALUES

#if ERROR_MESSAGES
#define print_error(STR) printk(KERN_ALERT "ERROR: %s (%s, %s:%d)\n",STR,__FUNCTION__,__FILE__,__LINE__)
#define print_error_message(FORMAT,ARGS...){\
             printk(KERN_ALERT "ERROR: (%s, %s:%d)",__FUNCTION__,__FILE__,__LINE__); \
             printk(KERN_ALERT FORMAT,##ARGS); \
             printk(KERN_ALERT "\n"); }
#define print_error_nomem() print_error("Malloc Failed: Out of Memory")
#else
#define print_error(STR)
#define print_error_message(FORMAT,ARGS...)
#define print_error_nomem()
#endif

#if WARNING_MESSAGES
#define print_warning_message(FORMAT,ARGS...) {\
             printk(KERN_ALERT "WARNING: %s() - ",__FUNCTION__); \
             printk(KERN_ALERT FORMAT,##ARGS); \
             printk(KERN_ALERT "\n"); }
#else
#define print_warning_message(FORMAT,ARGS...)
#endif


#endif //#ifndef __DEBUG_H
